@@ -13,9 +13,16 @@ module RR
       end
       attr_writer :instance
 
-    protected
-      def method_missing(method_name, *args, &block)
-        instance.__send__(method_name, *args, &block)
+      protected
+      if KeywordArguments.fully_supported?
+        def method_missing(method_name, *args, **kwargs, &block)
+          instance.__send__(method_name, *args, **kwargs, &block)
+        end
+      else
+        def method_missing(method_name, *args, &block)
+          instance.__send__(method_name, *args, &block)
+        end
+        ruby2_keywords(:method_missing) if respond_to?(:ruby2_keywords, true)
       end
     end
 
@@ -79,8 +86,12 @@ module RR
       Injections::DoubleInjection.reset_double(class << subject; self; end, method_name)
     end
 
-    def record_call(subject, method_name, arguments, block)
-      @recorded_calls << [subject, method_name, arguments, block]
+    def record_call(subject, method_name, arguments, keyword_arguments, block)
+      @recorded_calls.add(subject,
+                          method_name,
+                          arguments,
+                          keyword_arguments,
+                          block)
     end
 
     def blank_slate_whitelist
